pilas.actores.pingu

Package pilas :: Package actores :: Module pingu |
[hide private]
[frames] | no frames]

# Module pingu

source code

Classes | [hide private]
| Pingu Muestra a un pingüino que sabe caminar con el teclado.
| Esperando Un actor en posicion normal o esperando a que el usuario pulse alguna tecla.
| Caminando Representa al personaje caminando por el escenario.
| Saltando Representa al actor saltando con animación.

Variables | [hide private]
| VELOCIDAD = `4`
| __package__ = ``'``pilas.actores``'``